@@ -12,7 +12,7 @@ from typing import List, Optional
 
 from michael960lib.math import fourier
 from michael960lib.common import overrides, ModifyingReadOnlyObjectError, IllegalActionError
-from torusgrid.fields import RealField2D, import_field, real_convolution_2d, FieldStateFunction
+from torusgrid.fields import RealField2D, import_field, FieldStateFunction
 from torusgrid.dynamics import FreeEnergyFunctional2D, NoiseGenerator2D
 
 
