@@ -15,7 +15,7 @@ from michael960lib.math import fourier
 from michael960lib.common import overrides, experimental, deprecated
 from michael960lib.common import ModifyingReadOnlyObjectError, IllegalActionError
 from torusgrid.fields import RealField2D, import_field
-from torusgrid.dynamics import FieldEvolver, FancyEvolver, NoiseGenerator2D, FreeEnergyFunctional2D, EvolverHistory
+from torusgrid.dynamics import FancyEvolver, NoiseGenerator2D, FreeEnergyFunctional2D, EvolverHistory
 from .base import PFCStateFunction, PFCFreeEnergyFunctional, import_state_function
 
 
@@ -519,7 +519,6 @@ class RandomStepMinimizer(PFCMinimizer):
 
 
 
-
 class PFCMinimizerHistory(EvolverHistory):
     def __init__(self):
         super().__init__()
