@@ -1,10 +1,13 @@
 from torusgrid import field_util
 
+# WIP
+
 class PFCEditor:
     def __init__(self):
         pass
 
-    def edit(self, field, )
+    def edit(self, field):
+        pass
 
 
 class PFCEditAction:
